@@ -2,11 +2,11 @@
 import datetime
 import json
 import logging
-from optparse import Option
 import os
 import shutil
 from dataclasses import dataclass
-from typing import List, Optional
+from typing import List, Optional,Union
+import decimal
 
 import pandas as pd
 from google.cloud import bigquery
@@ -59,26 +59,26 @@ class BigQuery():
     @dataclass
     class oSpParam():
         name: str
-        value: object
+        value: Union[str, int, float, decimal.Decimal, bool, datetime.datetime, datetime.date]
         type: str
 
     def execute_stored_procedure(self, sp_name: str, sp_params: List[oSpParam]) -> pd.DataFrame:
         logging.debug(f"BigQuery::execute_sp::{sp_name}")
-        sp_instruction_params = ",@".join(
+        sp_instruction_params = "@" + ",@".join(
             [sp_param.name for sp_param in sp_params])
 
         query = f"CALL `{sp_name}`({sp_instruction_params})"
         query_parameters = []
         for sp_param in sp_params:
             query_parameters.append(
-                ScalarQueryParameter(sp_param.name, sp_param.type, sp_param.value))  # type: ignore
+                ScalarQueryParameter(sp_param.name, sp_param.type, sp_param.value))  
 
         job_config = QueryJobConfig(query_parameters=query_parameters)
         query_results = self.execute_query(query, job_config)
         result_list = []
         for result in query_results:
             t = dict(**result)
-            result_list.append(t) 
+            result_list.append(t)
         return pd.DataFrame(result_list)
 
     def table_exists(self, table_id: str) -> bool:
@@ -203,8 +203,8 @@ class BigQuery():
 
         logging.debug("Query results loaded to the table {}".format(table_id))
 
-    def delete_partition(self, table_id: str, 
-                         partition_date: datetime.date, 
+    def delete_partition(self, table_id: str,
+                         partition_date: datetime.date,
                          partition_name: str = 'date') -> bool:
 
         if self.table_exists(table_id):
@@ -347,7 +347,7 @@ class BigQuery():
                             logging.debug(query)
                             df = self.bigquery_to_dataframe(query)
                             logging.debug(qualified_table_id +
-                                         ':' + str(len(df)))
+                                          ':' + str(len(df)))
                             df_list.append(df)
                         # concat the partitioned dataframes and save to csv
                         FileHelper.check_filepath(user_files_folder)
